import java.awt.*;

/**
 * Ein manipulierbares Rechteck, das sich selbst in ein Canvas zeichnet. 
 * 
 * @author	M. Koelling
 * @reused by	H. Koetter
 * @version 1.0  (5 March 2001)
 * @entlehnt und erweitert von der Square Klasse von M. Kolling
 */

public class Rechteck
{
    private int width;
    private int height;
	private int xPosition;
	private int yPosition;
	private String color;

    /**
     * Erzeugung eines neuen Rechtecks an einer vordefinierten Position und mit einer vordefinierten Farbe. 
     */
    public Rechteck()
    {
		width = 40;
		height = 20;
		xPosition = 60;
		yPosition = 50;
		color = "red";
		draw();
    }

    /**
     * Verschieben des Rechtecks horizontal um  'distance' Pixel.
     */
    public void moveHorizontal(int distance)
    {
		erase();
		xPosition += distance;
		draw();
    }

    /**
     * Verschieben des Rechtecks vertikal um 'distance' Pixel.
     */
    public void moveVertical(int distance)
    {
		erase();
		yPosition += distance;
		draw();
    }

    /**
     * Aendern von Hoehe und Breite (in Pixel). 
     */
    public void changeSize(int newHeight, int newWidth)
    {
		erase();
		height = newHeight;
		width = newWidth;
		draw();
    }

    /**
     * Aendern der Hoehe des Rechtecks (in Pixel). Hoehe muss >= 0 sein.
     */
    public void changeHeight(int newHeight)
    {
		erase();
		height = newHeight;
		width = width;
		draw();
    }

    /**
     * Aendern der Breite (in Pixel). Hoehe muss >= 0 sein.
     */
    public void changeWidth(int newWidth)
    {
		erase();
		height = height;
		width = newWidth;
		draw();
    }

    /**
     * Neuzeichnen des Rechtecks.
     */
    public void redrawRectangle()
    {
		erase();
		draw();
    }

    /**
     * Wechseln der Farbe. Gueltige Farben sind "red", "yellow", "blue", "green",
	 * "magenta" and "black".
     */
    public void changeColor(String newColor)
    {
		color = newColor;
		draw();
    }

	/*
	 * Zeichnen des Rechtecks mit den derzeitigen Werten auf dem Canvas.
	 */
	private void draw()
	{
		Canvas canvas = Canvas.getCanvas();
		canvas.setForegroundColour(color);
		canvas.fill(new Rectangle(xPosition, yPosition, width, height));
		canvas.wait(10);
	}

	/*
	 * Loeschen des Rechtecks auf dem Canvas.
	 */
	private void erase()
	{
		Canvas canvas = Canvas.getCanvas();
		canvas.erase(new Rectangle(xPosition, yPosition, width, height));
	}
}
